import javax.swing.JComponent;
import java.awt.*;
import java.awt.geom.*;
/**
 * A simple graphics component, displaying a shape that moves at every
 * redisplay, and then triggers a redisplay so the shape appears to
 * move continuously.  (Technically, whenever the internal state of what
 * is to be displayed, i.e. the location of the box, changes, there should
 * be a redisplay.)
 * Changes since version 9: added a call to "repaint", and reduced the speed
 * that the box moves so we have time to see it.
 * 
 * @author Stephen Bloch
 * @version 10, Sept 13 2006
 */
public class MyComponent extends JComponent
{
    // instance variables
    /** @since version 9 */
    private int x, y;
    /**
     * Constructor for objects of class MyComponent
     */
    public MyComponent()
    {
        // initialize instance variables
        this.x = 75;
        this.y = 58;
    }

    /**
     * Display some shapes and text.
     * 
     * @param  g    a Graphics context into which we are to draw
     */
    public void paintComponent (Graphics g) {
        final int BOX_WIDTH = 34, BOX_HEIGHT = 21;
        final int BOX_DX = 2, BOX_DY = 3;
        
        Graphics2D g2 = (Graphics2D)g;
        
        Rectangle box = new Rectangle (this.x, this.y, BOX_WIDTH, BOX_HEIGHT);
        g2.fill (box);
        
        // update the location
        this.x += BOX_DX;
        this.y += BOX_DY;
        
        // force another redisplay soon
        this.repaint (this.getVisibleRect());
    }
}
