import javax.swing.JComponent;
import javax.swing.Timer;
import java.awt.*;
import java.awt.geom.*;
import java.awt.event.*;

/**
 * A simple graphics component, displaying a box that moves continuously.
 * 
 * Changes since version 18: instead of the rather crude, inefficient, and
 * unreliable "count to a million" timer, we've installed a real Timer.
 * 
 * @author Stephen Bloch
 * @version 19, Feb 9 2009
 */
public class MyComponent extends JComponent implements ActionListener
{
    // instance variables
    /** @since version 11 */
    private Box theBox;
    /** @since version 13 */
    private Box box2, box3;
    private Rectangle blueBounds;
    private Rectangle currentBounds;
    /** @since version 19 */
    private Timer theTimer;
    /**
     * Constructor for objects of class MyComponent
     */
    public MyComponent()
    {
        // initialize instance variables
        this.theBox = new Box(Color.BLUE, 75, 58, 21, 34, 2, 3);
        this.box2 = new Box(Color.ORANGE, 300, 10, 15, 9, -2, 1);
        this.box3 = new Box(Color.GREEN, 400, 600, 5, 20, -2, -3);
        this.blueBounds = new Rectangle (20, 20, 300, 200);
        this.theTimer = new Timer(10 /* milliseconds */, this /* ActionListener */);
        this.theTimer.start();
    }

    public void actionPerformed (ActionEvent e)
    {
        // ignore the ActionEvent; the only thing it could be is the Timer.
        // force another redisplay soon
        this.repaint (this.getVisibleRect());

    }
    /**
     * Display a box.
     * 
     * @param  g    a Graphics context into which we are to draw
     */
    public void paintComponent (Graphics g) {
        Graphics2D g2 = (Graphics2D)g;
        
        g2.setColor (Color.BLUE);
        g2.draw (this.blueBounds);
        
        this.theBox.show (g2);
        this.box2.show (g2);
        this.box3.show (g2);
        
        // update the locations
        this.theBox.move (this.blueBounds);
        this.currentBounds = new Rectangle (0, 0, this.getWidth(), this.getHeight());
        this.box2.move (this.currentBounds);
        this.box3.move (this.currentBounds);
    }
}
